FontTableFunction

Struct FontTableFunction 

pub struct FontTableFunction {
    table_fn: Arc<dyn Fn(Tag) -> Option<FontBlob> + Send + Sync>,
    tables: Arc<PerTableData<OnceLock<Option<(AtomicU8, FontBlob)>>>>,
}
Lazy, per table font data provided by a function.

Fields

table_fn: Arc<dyn Fn(Tag) -> Option<FontBlob> + Send + Sync>tables: Arc<PerTableData<OnceLock<Option<(AtomicU8, FontBlob)>>>>

Implementations

Source

impl FontTableFunction

pub fn new(table_fn: Arc<dyn Fn(Tag) -> Option<FontBlob> + Send + Sync>) -> Self

Creates a new font table function with the given callback that should return a blob containing the table data for the requested tag.