pub struct FontVariation {
pub tag: Tag,
pub value: f32,
}Expand description
A variation setting for a font instance.
The tag identifies the axis, and the value is the desired value for that axis in user space.
Fields
tag: TagThe tag that identifies the axis.
value: f32The value for the axis in user space.
Implementations